aboutsummaryrefslogtreecommitdiffstats
path: root/yage/entity/space.h
diff options
context:
space:
mode:
authorYann Herklotz <ymherklotz@gmail.com>2018-04-29 22:56:18 +0100
committerYann Herklotz <ymherklotz@gmail.com>2018-04-29 22:56:18 +0100
commitc44456496fe13800e36b8bf257eb2bd5d94faa30 (patch)
treecadd16dd5b6b51dfa5f2365000922da35668ff72 /yage/entity/space.h
parent8745306ddc2db08d52caf1c3c456c0bc43a062b7 (diff)
downloadYAGE-c44456496fe13800e36b8bf257eb2bd5d94faa30.tar.gz
YAGE-c44456496fe13800e36b8bf257eb2bd5d94faa30.zip
Working on the entity system
Diffstat (limited to 'yage/entity/space.h')
-rw-r--r--yage/entity/space.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/yage/entity/space.h b/yage/entity/space.h
index 96154ffc..7f73dbbe 100644
--- a/yage/entity/space.h
+++ b/yage/entity/space.h
@@ -10,8 +10,10 @@
#define YAGE_ENGINE_SPACE_H
#include <vector>
+#include <memory>
#include "entitymanager.h"
+#include "system.h"
namespace yage
{
@@ -41,10 +43,11 @@ public:
private:
/**
* The subspaces of the Space that act on the data and on their respective
* component. These are specific to the Space, as other spaces might have
* different Systems and not act on the same entities.
*/
+ std::vector<std::unique_ptr<System>> systems_;
/**
* Manages all the entities in the system, can create them for the current
@@ -41,10 +43,11 @@ public:
private:
/**
- * The subspaces of the Space that act on the data and on their respective
+ * The systems of the Space that act on the data and on their respective
* component. These are specific to the Space, as other spaces might have
* different Systems and not act on the same entities.